Package: CSAR
Type: Package
Title: Statistical tools for the analysis of ChIP-seq data
Version: 1.64.0
Date: 2025-07-24
Author: Jose M Muino
Description: Statistical tools for ChIP-seq data analysis. The package
        includes the statistical method described in Kaufmann et al.
        (2009) PLoS Biology: 7(4):e1000090. Briefly, Taking the average
        DNA fragment size subjected to sequencing into account, the
        software calculates genomic single-nucleotide read-enrichment
        values. After normalization, sample and control are compared
        using a test based on the Poisson distribution. Test statistic
        thresholds to control the false discovery rate are obtained
        through random permutation.
Depends: R (>= 2.15.0), S4Vectors, IRanges, Seqinfo, GenomicRanges
Maintainer: Jose M Muino <jose.muino@live.com>
Suggests: ShortRead, Biostrings
Imports: stats, utils
License: Artistic-2.0
LazyLoad: yes
LazyData: yes
biocViews: ChIPSeq, Transcription, Genetics
git_url: https://git.bioconductor.org/packages/CSAR
git_branch: RELEASE_3_23
git_last_commit: ee5e58c
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: yes
Packaged: 2026-04-28 21:28:45 UTC; biocbuild
